/*
 * Copyright 2002-2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cache.config;

import java.lang.reflect.Method;

import org.springframework.cache.interceptor.KeyGenerator;

/**
 * A custom {@link KeyGenerator} that exposes the algorithm used to compute the key
 * for convenience in tests scenario.
 *
 * @author Stephane Nicoll
 */
public final class SomeCustomKeyGenerator implements KeyGenerator {

    @Override
    public Object generate(Object target, Method method, Object... params) {
        return generateKey(method.getName(), params);
    }

    /**
     * @see #generate(Object, java.lang.reflect.Method, Object...)
     */
    static Object generateKey(String methodName, Object... params) {
        final StringBuilder sb = new StringBuilder(methodName);
        for (Object param : params) {
            sb.append(param);
        }
        return sb.toString();
    }

}
